pub fn sort<T: PartialOrd>(input: &mut [T]) -> &mut [T]Expand description
Sorts an array with procrastination sort.
Procrastination sort takes any unsorted entries and pushes them to the end of the array for later. In practice, this results in a wrapping left shift of the remaining elements from the position of the unordered element to the end of the list until the number in the position is sorted with the one next in the array.
This is O(n^3). Be very afraid.